package CVSMonitor::Range::Files;

use strict;
use UNIVERSAL qw{isa can};
use base 'CVSMonitor::Range';

# Add Version information to the Range totals
sub add {
	my $self = shift;
	my $Source = can( $_[0], 'getChangeSets' ) ? shift : return undef;
	my $ChangeSets = $Source->getChangeSets or return undef;

	# Index the dates
	my %totals = ();
	$totals{$_->{date}} = $_ foreach @$self;

	# Work out what level of depth to use
	my $regex = CVSMonitor::DateDepth->isolate_regex( $self->depth ) or return undef;

	# Iterate over the change sets
	foreach my $ChangeSet ( @$ChangeSets ) {
		return undef unless $ChangeSet->date =~ $regex;
		next unless exists $totals{$1};
		my $key = $1;

		foreach my $Version ( $ChangeSet->getVersions ) {
			if ( $Version->created ) {
				$totals{$key}->{added}++;
			} elsif ( $Version->removed ) {
				$totals{$key}->{removed}++;
			}
		}
	}

	1;
}

# Get a hash of the totals for the Range
sub totals {
	my $self = shift;

	my $totals = {
		added => 0,
		removed => 0,
		};

	# Add up the dates
	foreach my $date ( @$self ) {
		$totals->{added} += $date->{added};
		$totals->{removed} += $date->{removed};
	}

	# Add the extra stuff
	$totals->{change} = $totals->{added} - $totals->{removed};

	$totals;
}

# For a given date, generate it's basic stats struct
sub getStatisticsStruct {
	my $either = shift;
	my $date   = isa( $_[0], 'CVSMonitor::DateDepth' ) ? shift : return undef;
	return {
		date    => $date->toString,
		added   => 0,
		removed => 0,
		};
}

1;

__END__

# Copyright (C) 2002-2004 Adam Kennedy
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# Should you wish to utilise this software under a different licence, 
# please contact the author.
